4.18. umbra.components.factory.scriptEditor.nodes — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.18. umbra.components.factory.scriptEditor.nodes

nodes.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class nodes.

Others:

## 4.18.1. Module Attributes

`umbra.components.factory.scriptEditor.nodes.` `LOGGER`

## 4.18.2. Classes

class `umbra.components.factory.scriptEditor.nodes.` `EditorNode`(editor=None, name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  This class factory defines `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class Editor node.

  Parameters: | name – Node name. ( String ) parent – Node parent. ( GraphModelNode ) children – Children. ( List ) roles – Roles. ( Dictionary ) nodeFlags – Node flags. ( Integer ) attributesFlags – Attributes flags. ( Integer ) **kwargs – Keywords arguments. ( ** )

  `editor`

    This method is the property for self.__editor attribute.

    Returns: | self.__editor. ( Editor )

class `umbra.components.factory.scriptEditor.nodes.` `FileNode`(path=None, name=None, parent=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  This class factory defines `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class File node.

  Parameters: | path – File path. ( String ) editor – File editor. ( Editor ) name – Node name. ( String ) parent – Node parent. ( GraphModelNode ) roles – Roles. ( Dictionary ) nodeFlags – Node flags. ( Integer ) attributesFlags – Attributes flags. ( Integer ) **kwargs – Keywords arguments. ( ** )

  `path`

    This method is the property for self.__path attribute.

    Returns: | self.__path. ( String )

class `umbra.components.factory.scriptEditor.nodes.` `DirectoryNode`(path=None, name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  This class factory defines `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class Directory node.

  Parameters: | path – Directory path. ( String ) name – Node name. ( String ) parent – Node parent. ( GraphModelNode ) children – Children. ( List ) roles – Roles. ( Dictionary ) nodeFlags – Node flags. ( Integer ) attributesFlags – Attributes flags. ( Integer ) **kwargs – Keywords arguments. ( ** )

  `path`

    This method is the property for self.__path attribute.

    Returns: | self.__path. ( String )

class `umbra.components.factory.scriptEditor.nodes.` `ProjectNode`(path=None, name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  This class factory defines `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class Project node.

  Parameters: | path – Project path. ( String ) name – Node name. ( String ) parent – Node parent. ( GraphModelNode ) children – Children. ( List ) roles – Roles. ( Dictionary ) nodeFlags – Node flags. ( Integer ) attributesFlags – Attributes flags. ( Integer ) **kwargs – Keywords arguments. ( ** )

  `path`

    This method is the property for self.__path attribute.

    Returns: | self.__path. ( String )

class `umbra.components.factory.scriptEditor.nodes.` `PatternNode`(name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  This class factory defines `umbra.patterns.factory.scriptEditor.searchAndReplace.SearchAndReplace` class search and replace pattern node.

  Parameters: | name – Node name. ( String ) parent – Node parent. ( GraphModelNode ) children – Children. ( List ) roles – Roles. ( Dictionary ) nodeFlags – Node flags. ( Integer ) attributesFlags – Attributes flags. ( Integer ) **kwargs – Keywords arguments. ( ** )

class `umbra.components.factory.scriptEditor.nodes.` `SearchFileNode`(name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  This class factory defines `umbra.patterns.factory.scriptEditor.searchInFiles.SearchInFiles` class search file node.

  Parameters: | name – Node name. ( String ) parent – Node parent. ( GraphModelNode ) children – Children. ( List ) roles – Roles. ( Dictionary ) nodeFlags – Node flags. ( Integer ) attributesFlags – Attributes flags. ( Integer ) **kwargs – Keywords arguments. ( ** )

class `umbra.components.factory.scriptEditor.nodes.` `SearchOccurenceNode`(name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  This class factory defines `umbra.patterns.factory.scriptEditor.searchInFiles.SearchInFiles` class search occurence node.

  Parameters: | name – Node name. ( String ) parent – Node parent. ( GraphModelNode ) children – Children. ( List ) roles – Roles. ( Dictionary ) nodeFlags – Node flags. ( Integer ) attributesFlags – Attributes flags. ( Integer ) **kwargs – Keywords arguments. ( ** )

class `umbra.components.factory.scriptEditor.nodes.` `ReplaceResultNode`(name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  This class factory defines `umbra.patterns.factory.scriptEditor.searchInFiles.SearchInFiles` class replace result node.

  Parameters: | name – Node name. ( String ) parent – Node parent. ( GraphModelNode ) children – Children. ( List ) roles – Roles. ( Dictionary ) nodeFlags – Node flags. ( Integer ) attributesFlags – Attributes flags. ( Integer ) **kwargs – Keywords arguments. ( ** )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »